# Get Microsoft C compiler

Example to detect a Microsoft C compiler from the Visual Studio:

```bash
cm run script "get cl" --path="C:\Program Files (x86)\Microsoft Visual Studio\2019\Community\VC\Tools\MSVC\14.29.30133\bin\Hostx64\x64"
```
